*************
API reference
*************

.. autosummary::
   :toctree: api

   parametrize_from_file
   parametrize_from_file.Namespace
   parametrize_from_file.voluptuous.Namespace
   parametrize_from_file.add_loader
   parametrize_from_file.drop_loader
   parametrize_from_file.load_parameters
   parametrize_from_file.ConfigError
